# React-Syntax-Sugar !!
![npm](https://badge.fury.io/js/react-syntax-sugar.svg)
[![travis](https://travis-ci.org/o1o9814/react-syntax-sugar.svg?branch=master)](https://travis-ci.org/o1o9814/react-syntax-sugar)
[![appveyor](https://ci.appveyor.com/api/projects/status/qlomn5rfkntmw604?svg=true)](https://ci.appveyor.com/project/o1o9814/react-syntax-sugar)
![license](https://img.shields.io/badge/license-MIT-blue.svg)

This is a Babel plugin that extends the React syntax. And it's like sugar.

This project was inspired by Vue.

## Do you use eslint?

Add eslint rules.

```json
"rules": {
  "no-undef": 0,
  "react/jsx-no-undef": 0,
  "no-unused-expressions": 0
}
```

## Installation

require npm module:
```bash
# React-syntax-sugar is build during installation.
npm install babel-cli -g
```

Install via NPM:
```bash
npm install react-syntax-sugar --save
```

Install via Yarn:
```bash
yarn add react-syntax-sugar
```

Babel config:

```
...
"plugins": [
  "react-syntax-sugar"
]
```

Very well followed.

## Syntax

### Template

In
```jsx
<template name="myTemplate">
  <p>Template!!</p>
</template>
```

Out
```jsx
const myTemplate = (props) => {
  return (<div>
    <p>Template!!</p>
  </div>);
};
```

> Using the Template Syntax, you can create a more stylish code.

```jsx
import { Component } from 'react';

<template name="myTemplate">
  <p>Template!!</p>
</template>

<template name="myTemplate2">
  <p>Template!!</p>
</template>

class MyApp extends Component {
  render() {
    return (<div className="myApp">
      <myTemplate />
      <myTemplate2 />
    </div>);
  }
}
```

### Conditional

In
```jsx
<div data-if={3 === 3} />
```

Out
```jsx
true ? <div /> : null
```

**OR**

In
```jsx
const myNum = 100;

<div className="myDiv" data-if={myNum === 100} />
```

Out
```jsx
const myNum = 100;

myNum === 100 ? <div className="myDiv" /> : null
```

**OR** (Else-if)

In
```jsx
const myNum = 100;

<div className="myDiv" data-if={myNum === 100} />
<div className="myDiv2" data-else-if={myNum === 200} />
```

Out
```jsx
myNum === 100 ? <div className="myDiv" /> :
myNum === 200 ? <div className="myDiv2" /> : null
```

**OR** (Else)

In
```jsx
const myNum = 100;

<div className="myDiv" data-if={myNum === 100} />
<div className="myDiv2" data-else-if={myNum === 200} />
<div className="myDiv3" data-else />
```

Out
```jsx
myNum === 100 ? <div className="myDiv" /> :
myNum === 200 ? <div className="myDiv2" /> : 
                <div className="myDiv3" />
```

**OR**

In
```jsx
const myNum = 100;

<div className="myDiv" data-if={myNum === 100} />
<div className="myDiv2" data-else />
```

Out
```jsx
myNum === 100 ? <div className="myDiv" /> :
                <div className="myDiv2" />
```

### Loop

In
```jsx
const items = [1, 2, 3];

<p data-for="item in items">
  {item}
</p>
```

Out
```jsx
items.map(item => {
  return <p>{item}</p>
});
```

**OR**

In
```jsx
const items = [1, 2, 3];

<p data-for="(item, index) in items" key={index} />
```

Out
```jsx
items.map((item, index) => {
  return <p key={index} />
});
```

### Apply

In
```jsx
<template name="myTemplate" data-if={3 === 5}>
    <p>Hi!</p>
</template>
```

Out
```jsx
const myTemplate = (props) => {
  return 3 === 5 ? (<div>
    <p>Hi!</p>
  </div>) : null;
};
```

**OR**

In
```jsx
const items = [1, 2, 3]; 

<template name="myTemplate" data-for="(item, index) in items">
    <p>Hi!</p>
</template>
```

Out
```jsx
const myTemplate = (props) => {
  return items.map((item, index) => {
    return (<div>
      <p>Hi!</p>
    </div>);
  });
};
```