import TemplateSyntax from './syntax/TemplateSyntax';
import ConditionalSyntax from './syntax/ConditionalSyntax';
import LoopSyntax from './syntax/LoopSyntax';

import Util from './/util';

const handlers = {
  template: TemplateSyntax,
};

const controls = {
  'data-if': ConditionalSyntax,
  'data-for': LoopSyntax,
};

export default function ({ types }) {
  return {
    visitor: {
      JSXElement(nodePath) {
        const nodeName = nodePath.node.openingElement.name.name;
        const handler = handlers[nodeName.toLowerCase()];

        if (handler) {
          nodePath.replaceWith(handler(types, nodePath));
        } else {
          const attributeNames = Util.getAttributes(nodePath).map(node => node.name.name.toLowerCase());
          attributeNames.forEach((name) => {
            const control = controls[name];
            if (control) {
              nodePath.replaceWith(control(types, nodePath));
            }
          });
        }
      },
    },
  };
}