import Util from '../util';

const attributeNames = {
  If: 'data-if',
  ElseIf: 'data-else-if',
  Else: 'data-else',
};

const conditionalSyntax = (types, nodePath, attributeName) => {
  const expression = Util.getAttribute(nodePath, attributeName).value.expression;
  const index = Util.getAttributeIndex(nodePath, attributeName);

  if (!expression || index === -1) {
    throw new TypeError('Conditional SyntaxError');
  }

  // 무한 루프를 피하기 위해 사용됩니다.
  // to avoid infinite loop.
  Util.removeAttribute(nodePath, index);

  return { expression, index };
};

const elseSyntax = (types, nodePath, conditioned) => {
  if (types.isJSXElement(nodePath.parent)) {
    let nodes = Util.getBetweenNodes(types, nodePath.parent, attributeNames.If, attributeNames.Else);
    if (nodes) {
      nodes = nodes[0];

      if (types.isJSXElement(nodes)) {
        conditioned.alternate = nodes;
      }
    }
  }
};

const elseIfSyntax = (types, nodePath) => {
  let rootConditional;
  if (types.isJSXElement(nodePath.parent)) {
    let conditional;

    const nodes = Util.getBetweenNodes(types, nodePath.parent, attributeNames.If, attributeNames.ElseIf);
    nodes.forEach((node) => {
      const { expression } = conditionalSyntax(types, node, attributeNames.ElseIf);
      if (!rootConditional) {
        rootConditional = types.conditionalExpression(expression, node, types.nullLiteral());

        conditional = rootConditional;
      } else {
        conditional.alternate = types.conditionalExpression(expression, node, types.nullLiteral());

        conditional = conditional.alternate;
      }
    });
  }

  return rootConditional;
};

const ifSyntax = (types, nodePath) => {
  const { expression } = conditionalSyntax(types, nodePath, attributeNames.If);
  const conditional = types.conditionalExpression(expression, nodePath.node, types.nullLiteral());

  const elseIfExpression = elseIfSyntax(types, nodePath);
  if (elseIfExpression) {
    conditional.alternate = elseIfExpression;
  }

  let elseConditional = conditional;
  while (!types.isNullLiteral(elseConditional.alternate)) {
    elseConditional = elseConditional.alternate;
  }

  elseSyntax(types, nodePath, elseConditional);

  return conditional;
};

export default ifSyntax;