import babelTemplate from 'babel-template';
import Util from '../util';

const originalTemplate = babelTemplate(`
  NAME.map((PARAMS) => {
    return ELEMENT;
  })
`);

const loopSyntax = (types, nodePath) => {
  const index = Util.getAttributeIndex(nodePath, 'data-for');

  if (index === -1) {
    throw new TypeError('Conditional SyntaxError');
  }


  let loopExpression = Util.getAttribute(nodePath, 'data-for');
  if (!loopExpression) {
    throw new SyntaxError('data-for attribute not found!');
  }

  loopExpression = loopExpression.value.value;
  loopExpression = loopExpression.split(/ in /)
                                 .map(variable => variable.trim());

  if (loopExpression.length !== 2) {
    throw new SyntaxError('data-for unknown syntax: A in B');
  }

  // 무한 루프를 피하기 위해 사용됩니다.
  // to avoid infinite loop.
  Util.removeAttribute(nodePath, index);

  const targetName = types.Identifier(loopExpression[1]);
  const params = types.Identifier(loopExpression[0].replace(/\(|\)/g, ''));

  const syntax = originalTemplate({
    NAME: targetName,
    PARAMS: params,
    ELEMENT: nodePath.node,
  });

  return syntax;
};

export default loopSyntax;