const getChildren = (nodePath) => {
  const children = nodePath.node ? [...nodePath.node.children] : [...nodePath.children];
  return children;
};

const createElement = (types, children, attribute) => {
  const opening = types.jSXOpeningElement(types.jSXIdentifier('div'), attribute || [], false);
  const closing = types.jSXClosingElement(types.jSXIdentifier('div'));

  return types.jSXElement(opening, closing, children, false);
};

const getAttributes = (nodePath) => {
  const attributes = nodePath.node ? [...nodePath.node.openingElement.attributes] :
                                      [...nodePath.openingElement.attributes];

  return attributes;
};

const getAttribute = (nodePath, name) => {
  let attributes = getAttributes(nodePath);
  attributes = attributes.find(attribute => attribute.name.name === name);

  return attributes;
};

const getAttributeIndex = (nodePath, name) => {
  const attribute = getAttribute(nodePath, name);
  const index = getAttributes(nodePath).indexOf(attribute);

  return index;
};

const getChildIndex = (nodePath, child) => {
  const children = getChildren(nodePath);

  return children.indexOf(child);
};

const removeChild = (nodePath, child) => {
  const index = getChildIndex(nodePath, child);
  if (nodePath.node) {
    nodePath.node.children.splice(index, 1);
  } else {
    nodePath.children.splice(index, 1);
  }
};

const removeAttribute = (nodePath, index) => {
  const openingElement = nodePath.node ? nodePath.node.openingElement.attributes :
                                          nodePath.openingElement.attributes;

  openingElement.splice(index, 1);
};

/*
 Remove and collects B nodes between index 0 node and A.

 * Parameter *
 param [String] nodeName - A
 param [String] targetName - B

 return [Array]
 */
const getBetweenNodes = (types, nodePath, nodeName, targetName) => {
  const result = [];

  const children = getChildren(nodePath).filter(node => types.isJSXElement(node));
  children.some((child) => {
    let attribute = getAttribute(child, targetName);

    if (attribute) {
      result.push(child);

      removeChild(nodePath, child);
      return false;
    } else {
      attribute = getAttribute(child, nodeName);
    }

    return attribute;
  });

  return result;
};

export default { getChildren, createElement, getAttributes, getAttribute, getAttributeIndex, getChildIndex, removeChild, removeAttribute, getBetweenNodes };
